clj-yfinance.validation

Input validation and range checking for Yahoo Finance parameters.

Input validation and range checking for Yahoo Finance parameters.
raw docstring

chart-time-paramsclj

(chart-time-params {:keys [period start end]})

Build time-related query parameters from period or start/end.

Build time-related query parameters from period or start/end.
sourceraw docstring

interval-range-warningsclj

(interval-range-warnings {:keys [interval period start end]})

Returns a vector of warning maps if interval may be invalid for given range. Returns empty vector if valid.

Returns a vector of warning maps if interval may be invalid for given range. Returns empty vector if valid.
sourceraw docstring

validate-optsclj

(validate-opts {:keys [period interval start end]})

Validate chart options, returning {:ok? true} or {:ok? false :error {...}}.

Validate chart options, returning {:ok? true} or {:ok? false :error {...}}.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries