Input validation and range checking for Yahoo Finance parameters.
Input validation and range checking for Yahoo Finance parameters.
(chart-time-params {:keys [period start end]})Build time-related query parameters from period or start/end.
Build time-related query parameters from period or start/end.
(interval-range-warnings {:keys [interval period start end]})Returns a vector of warning maps if interval may be invalid for given range. Returns empty vector if valid.
Returns a vector of warning maps if interval may be invalid for given range. Returns empty vector if valid.
(validate-opts {:keys [period interval start end]})Validate chart options, returning {:ok? true} or {:ok? false :error {...}}.
Validate chart options, returning {:ok? true} or {:ok? false :error {...}}.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |